'****************************************************************************************************
'*                                             niHSDIO
'*--------------------------------------------------------------------------------------------------
'*   Copyright Lib "niHSDIO.DLL" (c) National Instruments 2002, 2003.  All Rights Reserved.
'*--------------------------------------------------------------------------------------------------
'*
'* Title:    niHSDIO.bas
'* Purpose:  National Instruments High-Speed Digital I/O
'*           instrument driver declarations.
'*
'*****************************************************************************************************
Option Explicit
Option Base 0

'****************************************************************************************************
'*------------------------------- Instrument Driver Revision Information ---------------------------*
'****************************************************************************************************
Public Const  NIHSDIO_MAJOR_VERSION                = 1     '* Instrument driver major version  *
Public Const  NIHSDIO_MINOR_VERSION                = 400   '* Instrument driver minor version  *

Public Const  NIHSDIO_SUPPORTED_INSTRUMENT_MODELS  = "NI-PXI-6541, NI-PXI-6542, NI-PCI-6541, NI-PCI-6542, NI-PXI-6551, NI-PXI-6552, NI-PCI-6551, NI-PCI-6552, NI-PXI-6561, NI-PXI-6562, NI-PCI-6561, NI-PCI-6562"
Public Const  NIHSDIO_DRIVER_VENDOR                = "National Instruments"
Public Const  NIHSDIO_DRIVER_DESCRIPTION           = "NI-HSDIO instrument driver"

'***************************************************************************************************
'*------------------------------------------ Attribute Defines ------------------------------------*
'***************************************************************************************************

'* IVI Inherent Instrument Attributes *

'* Advanced Session Information *
Public Const  NIHSDIO_ATTR_LOGICAL_NAME                            = 1050305          '* ViString, read-only *


'********************************** Instrument-Specific Attributes *********************************

'* Base attributes *
Public Const  NIHSDIO_ATTR_DYNAMIC_CHANNELS                        = (1150000 + 2)    '* ViString *
Public Const  NIHSDIO_ATTR_STATIC_CHANNELS                         = (1150000 + 3)    '* ViString *

'* Device attributes *
Public Const  NIHSDIO_ATTR_TOTAL_ACQUISITION_MEMORY_SIZE           = (1150000 + 73)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_TOTAL_GENERATION_MEMORY_SIZE            = (1150000 + 74)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_SERIAL_NUMBER                           = (1150000 + 96)   '* ViString *

'* Voltage attributes *
Public Const  NIHSDIO_ATTR_DATA_VOLTAGE_LOW_LEVEL                  = (1150000 + 6)    '* ViReal64, channel-based *
Public Const  NIHSDIO_ATTR_DATA_VOLTAGE_HIGH_LEVEL                 = (1150000 + 7)    '* ViReal64, channel-based *
Public Const  NIHSDIO_ATTR_TRIGGER_VOLTAGE_LOW_LEVEL               = (1150000 + 8)    '* ViReal64 *
Public Const  NIHSDIO_ATTR_TRIGGER_VOLTAGE_HIGH_LEVEL              = (1150000 + 9)    '* ViReal64 *
Public Const  NIHSDIO_ATTR_EVENT_VOLTAGE_LOW_LEVEL                 = (1150000 + 79)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_EVENT_VOLTAGE_HIGH_LEVEL                = (1150000 + 80)   '* ViReal64 *

'* Channel attributes *
Public Const  NIHSDIO_ATTR_DATA_INTERPRETATION                     = (1150000 + 10)   '* ViInt32, channel-based *
Public Const  NIHSDIO_ATTR_INPUT_IMPEDANCE                         = (1150000 + 70)   '* ViReal64, channel-based *
Public Const  NIHSDIO_ATTR_DRIVE_TYPE                              = (1150000 + 139)  '* ViInt32, channel-based *

'* Clocking attributes *
Public Const  NIHSDIO_ATTR_REF_CLOCK_SOURCE                        = (1150000 + 11)   '* ViString *
Public Const  NIHSDIO_ATTR_REF_CLOCK_RATE                          = (1150000 + 12)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_REF_CLOCK_IMPEDANCE                     = (1150000 + 58)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_EXPORTED_REF_CLOCK_OUTPUT_TERMINAL      = (1150000 + 59)   '* ViString *
Public Const  NIHSDIO_ATTR_SAMPLE_CLOCK_SOURCE                     = (1150000 + 13)   '* ViString *
Public Const  NIHSDIO_ATTR_SAMPLE_CLOCK_RATE                       = (1150000 + 14)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_SAMPLE_CLOCK_IMPEDANCE                  = (1150000 + 60)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_EXPORTED_SAMPLE_CLOCK_MODE              = (1150000 + 61)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_SAMPLE_CLOCK_DELAY             = (1150000 + 62)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_EXPORTED_SAMPLE_CLOCK_OUTPUT_TERMINAL   = (1150000 + 63)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_SAMPLE_CLOCK_OFFSET            = (1150000 + 83)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_EXPORTED_ONBOARD_REF_CLOCK_OUTPUT_TERMINAL = (1150000 + 85)'* ViString *

'* Triggers attributes *
Public Const  NIHSDIO_ATTR_START_TRIGGER_TYPE                      = (1150000 + 32)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_START_TRIGGER_SOURCE       = (1150000 + 33)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_START_TRIGGER_EDGE         = (1150000 + 34)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_START_TRIGGER_IMPEDANCE    = (1150000 + 1)    '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_START_TRIGGER_POSITION     = (1150000 + 75)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_START_TRIGGER_TERMINAL_CONFIGURATION   = (1150000 + 98)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_START_TRIGGER_PATTERN     = (1150000 + 35)   '* ViString *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_START_TRIGGER_WHEN        = (1150000 + 36)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_START_TRIGGER_OUTPUT_TERMINAL  = (1150000 + 37)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_START_TRIGGER_TERMINAL_CONFIGURATION   = (1150000 + 118)    '* ViInt32 *

Public Const  NIHSDIO_ATTR_REF_TRIGGER_TYPE                        = (1150000 + 38)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_REF_TRIGGER_SOURCE         = (1150000 + 39)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_REF_TRIGGER_EDGE           = (1150000 + 40)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_REF_TRIGGER_IMPEDANCE      = (1150000 + 4)    '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_REF_TRIGGER_POSITION       = (1150000 + 77)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_REF_TRIGGER_TERMINAL_CONFIGURATION     =  (1150000 + 99)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_REF_TRIGGER_PATTERN       =  (1150000 + 41)   '* ViString *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_REF_TRIGGER_WHEN          =  (1150000 + 42)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_REF_TRIGGER_OUTPUT_TERMINAL    =  (1150000 + 43)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_REF_TRIGGER_TERMINAL_CONFIGURATION    =  (1150000 + 119)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_START_TO_REF_TRIGGER_HOLDOFF            =  (1150000 + 86)   '* ViReal64, seconds *
Public Const  NIHSDIO_ATTR_REF_TO_REF_TRIGGER_HOLDOFF              =  (1150000 + 129)  '* ViReal64, seconds *

Public Const  NIHSDIO_ATTR_SCRIPT_TRIGGER_TYPE                     =  (1150000 + 44)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_SCRIPT_TRIGGER_SOURCE      =  (1150000 + 45)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_SCRIPT_TRIGGER_EDGE        =  (1150000 + 46)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_SCRIPT_TRIGGER_IMPEDANCE   =  (1150000 + 5)    '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_SCRIPT_TRIGGER_TERMINAL_CONFIGURATION  =  (1150000 + 100)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_SCRIPT_TRIGGER_SOURCE     =  (1150000 + 47)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_SCRIPT_TRIGGER_WHEN       =  (1150000 + 48)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_SCRIPT_TRIGGER_IMPEDANCE  =  (1150000 + 105)  '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_SCRIPT_TRIGGER_TERMINAL_CONFIGURATION   = (1150000 + 106)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_SCRIPT_TRIGGER_OUTPUT_TERMINAL =  (1150000 + 49)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_SCRIPT_TRIGGER_TERMINAL_CONFIGURATION   =  (1150000 + 120)    '* ViInt32 *

Public Const  NIHSDIO_ATTR_PAUSE_TRIGGER_TYPE                      =  (1150000 + 50)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_PAUSE_TRIGGER_SOURCE      =  (1150000 + 51)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_PAUSE_TRIGGER_WHEN        =  (1150000 + 52)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_PAUSE_TRIGGER_IMPEDANCE   =  (1150000 + 15)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_PAUSE_TRIGGER_POSITION    =  (1150000 + 87)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_LEVEL_PAUSE_TRIGGER_TERMINAL_CONFIGURATION  = (1150000 + 101)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_PAUSE_TRIGGER_PATTERN     =  (1150000 + 53)   '* ViString *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_PAUSE_TRIGGER_WHEN        =  (1150000 + 54)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_PAUSE_TRIGGER_OUTPUT_TERMINAL  =  (1150000 + 55)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_PAUSE_TRIGGER_TERMINAL_CONFIGURATION    = (1150000 + 121)    '* ViInt32 *

Public Const  NIHSDIO_ATTR_ADVANCE_TRIGGER_TYPE                      =  (1150000 + 88)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_ADVANCE_TRIGGER_SOURCE       =  (1150000 + 89)   '* ViString *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_ADVANCE_TRIGGER_EDGE         =  (1150000 + 90)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_ADVANCE_TRIGGER_IMPEDANCE    =  (1150000 + 95)   '* ViReal64 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_ADVANCE_TRIGGER_POSITION     =  (1150000 + 93)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DIGITAL_EDGE_ADVANCE_TRIGGER_TERMINAL_CONFIGURATION    =  (1150000 + 107)    '* ViInt32 *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_ADVANCE_TRIGGER_PATTERN     =  (1150000 + 91)   '* ViString *
Public Const  NIHSDIO_ATTR_PATTERN_MATCH_ADVANCE_TRIGGER_WHEN        =  (1150000 + 92)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_EXPORTED_ADVANCE_TRIGGER_OUTPUT_TERMINAL  =  (1150000 + 94)   '* ViString *
Public Const  NIHSDIO_ATTR_EXPORTED_ADVANCE_TRIGGER_TERMINAL_CONFIGURATION   =  (1150000 + 122)    '* ViInt32 *

'* Events attributes *
Public Const  NIHSDIO_ATTR_READY_FOR_START_EVENT_OUTPUT_TERMINAL           =  (1150000 + 16)   '* ViString *
Public Const  NIHSDIO_ATTR_READY_FOR_START_EVENT_LEVEL_ACTIVE_LEVEL        =  (1150000 + 17)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_READY_FOR_START_EVENT_TERMINAL_CONFIGURATION    =  (1150000 + 102)  '* ViInt32 *

Public Const  NIHSDIO_ATTR_DATA_ACTIVE_EVENT_OUTPUT_TERMINAL        =  (1150000 + 19)   '* ViString *
Public Const  NIHSDIO_ATTR_DATA_ACTIVE_EVENT_LEVEL_ACTIVE_LEVEL     =  (1150000 + 20)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DATA_ACTIVE_EVENT_POSITION               =  (1150000 + 81)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DATA_ACTIVE_EVENT_TERMINAL_CONFIGURATION =  (1150000 + 103)  '* ViInt32 *

Public Const  NIHSDIO_ATTR_MARKER_EVENT_OUTPUT_TERMINAL              =  (1150000 + 22)   '* ViString *
Public Const  NIHSDIO_ATTR_MARKER_EVENT_PULSE_POLARITY               =  (1150000 + 23)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_MARKER_EVENT_POSITION                     =  (1150000 + 82)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_MARKER_EVENT_TERMINAL_CONFIGURATION       =  (1150000 + 104)  '* ViInt32 *

Public Const  NIHSDIO_ATTR_READY_FOR_ADVANCE_EVENT_OUTPUT_TERMINAL        =  (1150000 + 109)   '* ViString *
Public Const  NIHSDIO_ATTR_READY_FOR_ADVANCE_EVENT_LEVEL_ACTIVE_LEVEL     =  (1150000 + 110)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_READY_FOR_ADVANCE_EVENT_TERMINAL_CONFIGURATION =  (1150000 + 111)   '* ViInt32 *

Public Const  NIHSDIO_ATTR_END_OF_RECORD_EVENT_OUTPUT_TERMINAL          =  (1150000 + 112)   '* ViString *
Public Const  NIHSDIO_ATTR_END_OF_RECORD_EVENT_PULSE_POLARITY           =  (1150000 + 113)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_END_OF_RECORD_EVENT_TERMINAL_CONFIGURATION   =  (1150000 + 114)   '* ViInt32 *

Public Const  NIHSDIO_ATTR_HWC_SAMPLE_ERROR_EVENT_OUTPUT_TERMINAL       =  (1150000 + 136) '* ViString *

'* Dynamic output attributes *
Public Const  NIHSDIO_ATTR_GENERATION_MODE                         =  (1150000 + 25)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_REPEAT_MODE                             =  (1150000 + 26)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_REPEAT_COUNT                            =  (1150000 + 71)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_WAVEFORM_TO_GENERATE                    =  (1150000 + 27)   '* ViString *
Public Const  NIHSDIO_ATTR_SCRIPT_TO_GENERATE                      =  (1150000 + 28)   '* ViString *
Public Const  NIHSDIO_ATTR_INITIAL_STATE                           =  (1150000 + 64)   '* ViInt32, channel-based *
Public Const  NIHSDIO_ATTR_IDLE_STATE                              =  (1150000 + 65)   '* ViInt32, channel-based *

'* Dynamic input attributes *
Public Const  NIHSDIO_ATTR_SAMPLES_PER_RECORD                     =  (1150000 + 29)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_NUM_RECORDS                            =  (1150000 + 126)  '* ViInt32 *
Public Const  NIHSDIO_ATTR_REF_TRIGGER_PRETRIGGER_SAMPLES         =  (1150000 + 30)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_FETCH_BACKLOG                          =  (1150000 + 31)   '* ViInt32, read-only *
Public Const  NIHSDIO_ATTR_FETCH_RELATIVE_TO                      =  (1150000 + 67)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_FETCH_OFFSET                           =  (1150000 + 68)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_RECORDS_DONE                           =  (1150000 + 125)  '* ViInt32 *
Public Const  NIHSDIO_ATTR_DATA_ACTIVE_INTERNAL_ROUTE_DELAY       =  (1150000 + 138)  '* ViInt32 *

'* Data Position Delay *
Public Const  NIHSDIO_ATTR_DATA_POSITION                           =  (1150000 + 56)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_DATA_POSITION_DELAY                     =  (1150000 + 57)   '* ViReal64 *

'* Data Width *
Public Const  NIHSDIO_ATTR_DATA_WIDTH                              =  (1150000 + 108)   '* ViInt32 *

'* Data Rate Multiplier *
Public Const  NIHSDIO_ATTR_DATA_RATE_MULTIPLIER                    =  (1150000 + 128)   '* ViInt32 *

'* Synchronization attributes *
Public Const  NIHSDIO_ATTR_DAQMX_TASK                              =  (1150000 + 69)   '* ViInt32 *
Public Const  NIHSDIO_ATTR_OSCILLATOR_PHASE_DAC_VALUE              =  (1150000 + 72)   '* ViInt32 *

'* Hardware compare *
Public Const  NIHSDIO_ATTR_HWC_HARDWARE_COMPARE_MODE               =  (1150000 + 130)  '* ViInt32 *
Public Const  NIHSDIO_ATTR_HWC_SAMPLE_ERROR_BACKLOG                =  (1150000 + 132)  '* ViInt32 *
Public Const  NIHSDIO_ATTR_HWC_NUM_SAMPLE_ERRORS                   =  (1150000 + 133)  '* ViInt32 *
Public Const  NIHSDIO_ATTR_HWC_SAMPLES_COMPARED                    =  (1150000 + 134)  '* ViReal64 *
Public Const  NIHSDIO_ATTR_HWC_FILTER_REPEATED_SAMPLE_ERRORS       =  (1150000 + 140)  '* ViBoolean *
Public Const  NIHSDIO_ATTR_HWC_SAMPLE_ERROR_BUFFER_OVERFLOWED      =  (1150000 + 135)  '* ViBoolean *

'***************************************************************************************************
'*----------------------------------- Attribute Value Defines -------------------------------------*
'***************************************************************************************************

'************************** Instrument specific attribute value definitions ************************

'* Data interpretation *
Public Const  NIHSDIO_VAL_HIGH_OR_LOW                        = 3
Public Const  NIHSDIO_VAL_VALID_OR_INVALID                   =  4

'* Drive type *
Public Const  NIHSDIO_VAL_ACTIVE_DRIVE                       =  75
Public Const  NIHSDIO_VAL_OPEN_COLLECTOR                     =  76

'* Logic family *
Public Const  NIHSDIO_VAL_5_0V_LOGIC                         =  5
Public Const  NIHSDIO_VAL_3_3V_LOGIC                         =  6
Public Const  NIHSDIO_VAL_2_5V_LOGIC                         =  7
Public Const  NIHSDIO_VAL_1_8V_LOGIC                         =  8

'* Digital edge *
Public Const  NIHSDIO_VAL_RISING_EDGE                        =  12
Public Const  NIHSDIO_VAL_FALLING_EDGE                       =  13

'* Pattern Match Values *
Public Const  NIHSDIO_VAL_IGNORE                             =  33
Public Const  NIHSDIO_VAL_MATCH_LOW                          =  0
Public Const  NIHSDIO_VAL_MATCH_HIGH                         =  1

'* Trigger digital pattern trigger when *
Public Const  NIHSDIO_VAL_PATTERN_MATCHES                    =  36
Public Const  NIHSDIO_VAL_PATTERN_DOES_NOT_MATCH             =  37

'* Event polarity *
Public Const  NIHSDIO_VAL_ACTIVE_HIGH                        =  10
Public Const  NIHSDIO_VAL_ACTIVE_LOW                         =  11

'* Generation mode *
Public Const  NIHSDIO_VAL_WAVEFORM                           =  14
Public Const  NIHSDIO_VAL_SCRIPTED                           =  15

'* Repeat mode *
Public Const  NIHSDIO_VAL_FINITE                             =  16
Public Const  NIHSDIO_VAL_CONTINUOUS                         =  17

'* Data Position Delay *
Public Const  NIHSDIO_VAL_SAMPLE_CLOCK_RISING_EDGE           =  18
Public Const  NIHSDIO_VAL_SAMPLE_CLOCK_FALLING_EDGE          =  19
Public Const  NIHSDIO_VAL_DELAY_FROM_SAMPLE_CLOCK_RISING_EDGE=  20

'* Exported Sample Clock Inversion/Delay *
Public Const  NIHSDIO_VAL_NONINVERTED                        =  21
Public Const  NIHSDIO_VAL_INVERTED                           =  22
Public Const  NIHSDIO_VAL_DELAYED                            =  23

'* Initial/Idle State *
Public Const  NIHSDIO_VAL_TRISTATE                           =  24
Public Const  NIHSDIO_VAL_LOGIC_HIGH                         =  1
Public Const  NIHSDIO_VAL_LOGIC_LOW                          =  0
Public Const  NIHSDIO_VAL_HOLD_LAST_VALUE                    =  27

'* Trigger Types *
Public Const  NIHSDIO_VAL_NONE                               =  28
Public Const  NIHSDIO_VAL_DIGITAL_EDGE                       =  29
Public Const  NIHSDIO_VAL_DIGITAL_LEVEL                      =  30
Public Const  NIHSDIO_VAL_PATTERN_MATCH                      =  31
Public Const  NIHSDIO_VAL_SOFTWARE                           =  32

'* Level Trigger Values *
Public Const  NIHSDIO_VAL_HIGH                               =  34
Public Const  NIHSDIO_VAL_LOW                                =  35

'* Write Position Value *
Public Const  NIHSDIO_VAL_START_OF_WAVEFORM                  =  44
Public Const  NIHSDIO_VAL_CURRENT_POSITION                   =  45

'* Fetch Position Value *
Public Const  NIHSDIO_VAL_MOST_RECENT_SAMPLE                 =  46
Public Const  NIHSDIO_VAL_FIRST_SAMPLE                       =  47
Public Const  NIHSDIO_VAL_REFERENCE_TRIGGER                  =  48
Public Const  NIHSDIO_VAL_FIRST_PRETRIGGER_SAMPLE            =  49
Public Const  NIHSDIO_VAL_CURRENT_READ_POSITION              =  50

'* Signal Values *
Public Const  NIHSDIO_VAL_SAMPLE_CLOCK                       =  51
Public Const  NIHSDIO_VAL_REF_CLOCK                          =  52
Public Const  NIHSDIO_VAL_START_TRIGGER                      =  53
Public Const  NIHSDIO_VAL_REF_TRIGGER                        =  54
Public Const  NIHSDIO_VAL_DATA_ACTIVE_EVENT                  =  55
Public Const  NIHSDIO_VAL_READY_FOR_START_EVENT              =  56
Public Const  NIHSDIO_VAL_READY_FOR_ADVANCE_EVENT            =  66
Public Const  NIHSDIO_VAL_END_OF_RECORD_EVENT                =  68
Public Const  NIHSDIO_VAL_PAUSE_TRIGGER                      =  57
Public Const  NIHSDIO_VAL_SCRIPT_TRIGGER                     =  58
Public Const  NIHSDIO_VAL_MARKER_EVENT                       =  59
Public Const  NIHSDIO_VAL_ONBOARD_REF_CLOCK                  =  60
Public Const  NIHSDIO_VAL_ADVANCE_TRIGGER                    =  61

'* Timestamp Type Values *
Public Const  NIHSDIO_VAL_TIMESTAMP_ABSOLUTE                 =  69
Public Const  NIHSDIO_VAL_TIMESTAMP_RELATIVE                 =  70

'* Calibration values *
Public Const  NIHSDIO_VAL_EXT_CAL_COMMIT                     =  62
Public Const  NIHSDIO_VAL_EXT_CAL_CANCEL                     =  63

'* Terminal Configuration Values *
Public Const  NIHSDIO_VAL_LVDS                               =  64
Public Const  NIHSDIO_VAL_SINGLE_ENDED                       =  65

'* Data Rate Mode Values *
Public Const  NIHSDIO_VAL_SINGLE_DATA_RATE                   =  1
Public Const  NIHSDIO_VAL_DOUBLE_DATA_RATE                   =  2

'* Data Layout Values for WDT *
Public Const  NIHSDIO_VAL_GROUP_BY_SAMPLE                    =  71
Public Const  NIHSDIO_VAL_GROUP_BY_CHANNEL                   =  72

'* Expected Data FIFO Mode Values *
Public Const  NIHSDIO_VAL_HWC_DISABLED                       =  77
Public Const  NIHSDIO_VAL_HWC_STIMULUS_AND_EXPECTED_RESPONSE =  78
Public Const  NIHSDIO_VAL_HWC_EXPECTED_RESPONSE_ONLY         =  79

'****** String enum values for terminal names Lib "niHSDIO.DLL" (used for CVI Get/Set Attribute functions only) *******
Public Const  NIHSDIO_VAL_DO_NOT_EXPORT_STR                    = ""
Public Const  NIHSDIO_VAL_PFI0_STR                             = "PFI0"
Public Const  NIHSDIO_VAL_PFI1_STR                             = "PFI1"
Public Const  NIHSDIO_VAL_PFI2_STR                             = "PFI2"
Public Const  NIHSDIO_VAL_PFI3_STR                             = "PFI3"
Public Const  NIHSDIO_VAL_PXI_TRIG0_STR                        = "PXI_Trig0"
Public Const  NIHSDIO_VAL_PXI_TRIG1_STR                        = "PXI_Trig1"
Public Const  NIHSDIO_VAL_PXI_TRIG2_STR                        = "PXI_Trig2"
Public Const  NIHSDIO_VAL_PXI_TRIG3_STR                        = "PXI_Trig3"
Public Const  NIHSDIO_VAL_PXI_TRIG4_STR                        = "PXI_Trig4"
Public Const  NIHSDIO_VAL_PXI_TRIG5_STR                        = "PXI_Trig5"
Public Const  NIHSDIO_VAL_PXI_TRIG6_STR                        = "PXI_Trig6"
Public Const  NIHSDIO_VAL_PXI_TRIG7_STR                        = "PXI_Trig7"
Public Const  NIHSDIO_VAL_PXI_STAR_STR                         = "PXI_STAR"
Public Const  NIHSDIO_VAL_CLK_OUT_STR                          = "ClkOut"
Public Const  NIHSDIO_VAL_DDC_CLK_OUT_STR                      = "DDC_ClkOut"
Public Const  NIHSDIO_VAL_ON_BOARD_CLOCK_STR                   = "OnBoardClock"
Public Const  NIHSDIO_VAL_CLK_IN_STR                           = "ClkIn"
Public Const  NIHSDIO_VAL_PXI_CLK10_STR                        = "PXI_CLK10"
Public Const  NIHSDIO_VAL_STROBE_STR                           = "STROBE"
Public Const  NIHSDIO_VAL_NONE_STR                             = "None"
Public Const  NIHSDIO_VAL_RTSI0_STR                            = "RTSI0"
Public Const  NIHSDIO_VAL_RTSI1_STR                            = "RTSI1"
Public Const  NIHSDIO_VAL_RTSI2_STR                            = "RTSI2"
Public Const  NIHSDIO_VAL_RTSI3_STR                            = "RTSI3"
Public Const  NIHSDIO_VAL_RTSI4_STR                            = "RTSI4"
Public Const  NIHSDIO_VAL_RTSI5_STR                            = "RTSI5"
Public Const  NIHSDIO_VAL_RTSI6_STR                            = "RTSI6"
Public Const  NIHSDIO_VAL_RTSI7_STR                            = "RTSI7"

'****** String enum values for signal names *******
Public Const  NIHSDIO_VAL_SCRIPT_TRIGGER0                      = "scriptTrigger0"
Public Const  NIHSDIO_VAL_SCRIPT_TRIGGER1                      = "scriptTrigger1"
Public Const  NIHSDIO_VAL_SCRIPT_TRIGGER2                      = "scriptTrigger2"
Public Const  NIHSDIO_VAL_SCRIPT_TRIGGER3                      = "scriptTrigger3"
Public Const  NIHSDIO_VAL_MARKER_EVENT0                        = "marker0"
Public Const  NIHSDIO_VAL_MARKER_EVENT1                        = "marker1"
Public Const  NIHSDIO_VAL_MARKER_EVENT2                        = "marker2"
Public Const  NIHSDIO_VAL_MARKER_EVENT3                        = "marker3"

'************************************* Digital Channel States **************************************

Public Const  NI_DIO_0  = 0
Public Const  NI_DIO_1  = 1
Public Const  NI_DIO_Z  = 2
Public Const  NI_DIO_L  = 3
Public Const  NI_DIO_H  = 4
Public Const  NI_DIO_X  = 5
Public Const  NI_DIO_T  = 6
Public Const  NI_DIO_V  = 7

'***************************************************************************************************
'*---------------------------- Instrument Driver Function Declarations ----------------------------*
'***************************************************************************************************

'* Init and Close Functions * niHSDIO.dll
Public Declare Function niHSDIO_InitAcquisitionSession Lib "niHSDIO.DLL" (ByVal resourceName as String,ByVal IDQuery as Integer,ByVal resetDevice as Integer, ByVal optionString as String, ByRef vi as Long) as Long
Public Declare Function niHSDIO_InitGenerationSession Lib "niHSDIO.DLL" (ByVal resourceName as String,ByVal IDQuery as Integer,ByVal resetDevice as Integer, ByVal optionString as String,ByRef vi as Long) as Long
Public Declare Function niHSDIO_close Lib "niHSDIO.DLL" (ByVal vi as Long) as Long

'* Locking Functions *
Public Declare Function niHSDIO_LockSession Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef callerHasLock as Integer) as Long
Public Declare Function niHSDIO_UnlockSession Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef callerHasLock as Integer) as Long

'* Control Functions *
Public Declare Function niHSDIO_Initiate Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_Abort Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_CommitStatic Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_CommitDynamic Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_WaitUntilDone Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal maxTime as Long) as Long
Public Declare Function niHSDIO_IsDone Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef done as Integer) as Long
Public Declare Function niHSDIO_TristateChannels Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelList as String,ByVal tristate as Integer) as Long

'* Static I/O Functions *
Public Declare Function niHSDIO_AssignStaticChannels Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelList as String) as Long
Public Declare Function niHSDIO_WriteStaticU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal writeData as Long,ByVal channelMask as Long) as Long
Public Declare Function niHSDIO_ReadStaticU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef data as Long) as Long

'* Voltage Configuration Functions *
Public Declare Function niHSDIO_ConfigureDataVoltageLogicFamily Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelList as String,ByVal logicFamily as Long) as Long
Public Declare Function niHSDIO_ConfigureDataVoltageCustomLevels Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelList as String,ByVal lowLevel as Double,ByVal highLevel as Double) as Long
Public Declare Function niHSDIO_ConfigureTriggerVoltageLogicFamily Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal logicFamily as Long) as Long
Public Declare Function niHSDIO_ConfigureTriggerVoltageCustomLevels Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal lowLevel as Double,ByVal highLevel as Double) as Long
Public Declare Function niHSDIO_ConfigureEventVoltageLogicFamily Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal logicFamily as Long) as Long
Public Declare Function niHSDIO_ConfigureEventVoltageCustomLevels Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal lowLevel as Double,ByVal highLevel as Double) as Long

'* Timing Configuration Functions *
Public Declare Function niHSDIO_ConfigureRefClock Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal clockSource as String,ByVal clockRate as Double) as Long
Public Declare Function niHSDIO_ConfigureSampleClock Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal clockSource as String,ByVal clockRate as Double) as Long
Public Declare Function niHSDIO_ConfigureDataPosition Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal position as Long) as Long
Public Declare Function niHSDIO_ConfigureDataPositionDelay Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal delay as Double) as Long
Public Declare Function niHSDIO_AdjustSampleClockRelativeDelay Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal adjustmentTime as Double) as Long

'* Triggers Functions *
Public Declare Function niHSDIO_SendSoftwareEdgeTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal triggerName as Long,ByVal triggerIdentifier as String) as Long

Public Declare Function niHSDIO_ConfigureDigitalLevelPauseTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal source as String,ByVal level as Long) as Long
Public Declare Function niHSDIO_DisablePauseTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchPauseTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as String,ByVal triggerWhen as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchPauseTriggerU32 Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as Long,ByVal triggerWhen as Long) as Long

Public Declare Function niHSDIO_ConfigureDigitalEdgeScriptTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal triggerID as String,ByVal source as String,ByVal edge as Long) as Long
Public Declare Function niHSDIO_ConfigureDigitalLevelScriptTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal triggerID as String,ByVal source as String,ByVal level as Long) as Long
Public Declare Function niHSDIO_DisableScriptTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal triggerID as String) as Long
Public Declare Function niHSDIO_ConfigureSoftwareScriptTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal triggerID as String) as Long

Public Declare Function niHSDIO_ConfigureDigitalEdgeStartTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal source as String,ByVal edge as Long) as Long
Public Declare Function niHSDIO_DisableStartTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigureSoftwareStartTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchStartTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as String,ByVal triggerWhen as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchStartTriggerU32 Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as Long,ByVal triggerWhen as Long) as Long

Public Declare Function niHSDIO_ConfigureDigitalEdgeAdvanceTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal source as String,ByVal edge as Long) as Long
Public Declare Function niHSDIO_DisableAdvanceTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigureSoftwareAdvanceTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchAdvanceTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as String,ByVal triggerWhen as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchAdvanceTriggerU32 Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as Long,ByVal triggerWhen as Long) as Long

Public Declare Function niHSDIO_ConfigureDigitalEdgeRefTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal source as String,ByVal edge as Long,ByVal pretriggerSamples as Long) as Long
Public Declare Function niHSDIO_DisableRefTrigger Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ConfigureSoftwareRefTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal pretriggerSamples as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchRefTrigger Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as String,ByVal triggerWhen as Long,ByVal pretrigSamples as Long) as Long
Public Declare Function niHSDIO_ConfigurePatternMatchRefTriggerU32 Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal pattern as Long,ByVal triggerWhen as Long,ByVal pretrigSamples as Long) as Long

'* Events Functions *
Public Declare Function niHSDIO_ExportSignal Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal signal as Long,ByVal signalIdentifier as String,ByVal outputTerminal as String) as Long

'* Dynamic Generation Functions *
Public Declare Function niHSDIO_AssignDynamicChannels Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String) as Long
Public Declare Function niHSDIO_AllocateNamedWaveform Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal sizeInSamples as String) as Long
Public Declare Function niHSDIO_DeleteNamedWaveform Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String) as Long
Public Declare Function niHSDIO_WriteNamedWaveformU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal samplesToWrite as String,ByRef data as Long) as Long
Public Declare Function niHSDIO_WriteNamedWaveformU16 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal samplesToWrite as String,ByRef data as Integer) as Long
Public Declare Function niHSDIO_WriteNamedWaveformU8 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal samplesToWrite as String,ByRef data as Byte) as Long
Public Declare Function niHSDIO_WriteNamedWaveformWDT Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal samplesPerChannel as Long,ByVal dataLayout as Long,ByRef data as Byte) as Long
Public Declare Function niHSDIO_WriteNamedWaveformFromFileHWS Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal filePath as String,ByVal useRateFromWaveform as Integer,ByRef waveformSizeInSamples as Long) as Long
Public Declare Function niHSDIO_ConfigureGenerationMode Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal generationMode as Long) as Long
Public Declare Function niHSDIO_ConfigureGenerationRepeat Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal repeatMode as Long,ByVal repeatCount as Long) as Long
Public Declare Function niHSDIO_WriteScript Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal script as String) as Long
Public Declare Function niHSDIO_ConfigureWaveformToGenerate Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String) as Long
Public Declare Function niHSDIO_ConfigureScriptToGenerate Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal script as String) as Long
Public Declare Function niHSDIO_ConfigureInitialState Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal initialState as String) as Long
Public Declare Function niHSDIO_ConfigureInitialStateU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal initialState as Long) as Long
Public Declare Function niHSDIO_ConfigureIdleState Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal idleState as Long) as Long
Public Declare Function niHSDIO_ConfigureIdleStateU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal idleState as Long) as Long
Public Declare Function niHSDIO_SetNamedWaveformNextWritePosition Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal waveformName as String,ByVal relativeTo as Long,ByVal offset as Long) as Long

'* Dynamic Acquisition Functions *
Public Type niHSDIO_wfmInfo

    absoluteTimestamp as Double
    relativeTimestamp as Double
    dt as Double
    actualSamplesRead as Long
    reserved1 as Double
    reserved2 as Double
End Type

Public Declare Function niHSDIO_ConfigureAcquisitionSize Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesPerRecord as Long,ByVal numberOfRecords as Long) as Long
Public Declare Function niHSDIO_ConfigureDataInterpretation Lib "niHSDIO.DLL" (ByVal vi as Long,  ByVal channelList as String,ByVal dataInterpretation as Long) as Long
Public Declare Function niHSDIO_GetFetchBacklog Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal recordNumber as Long,ByRef backlog as Long) as Long
Public Declare Function niHSDIO_FetchMultiRecordU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Long,   ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_FetchMultiRecordU16 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Integer,ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_FetchMultiRecordU8 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Byte,ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_FetchWaveformU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Long) as Long
Public Declare Function niHSDIO_FetchWaveformU16 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Integer) as Long
Public Declare Function niHSDIO_FetchWaveformU8 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Byte) as Long
Public Declare Function niHSDIO_ReadWaveformU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Long) as Long
Public Declare Function niHSDIO_ReadWaveformU16 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Integer) as Long
Public Declare Function niHSDIO_ReadWaveformU8 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numberOfSamplesRead as Long,ByRef data as Byte) as Long
Public Declare Function niHSDIO_ReadMultiRecordU32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Long,ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_ReadMultiRecordU16 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Integer,ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_ReadMultiRecordU8 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal samplesToRead as Long,ByVal maxTimeMilliseconds as Long,ByVal startingRecord as Long,ByVal numberOfRecords as Long,ByRef data as Byte,ByRef wfmInfo as niHSDIO_wfmInfo) as Long
Public Declare Function niHSDIO_HWC_FetchSampleErrors Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal numSampleErrorsToRead as Long,ByVal maxTimeMilliseconds as Long,ByRef numSampleErrorsRead as Long,ByRef sampleNumber as Double,ByVal errorBits as Long,ByVal errorRepeatCount as Long,ByRef reserved1 as Long,ByRef reserved2 as Long) as Long

'* Error Functions *
Public Declare Function niHSDIO_error_message Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal errorCode as Long,ByVal errorMessage as String) as Long
Public Declare Function niHSDIO_GetError Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef errorCode as Long,ByVal errorDescriptionBufferSize as Long,ByVal errorDescription as String) as Long
Public Declare Function niHSDIO_ClearError Lib "niHSDIO.DLL" (ByVal vi as Long) as Long

'* Utility Functions *
Public Declare Function niHSDIO_reset Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_self_test Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef selfTestResult as Integer,ByVal selfTestMessage as String) as Long
Public Declare Function niHSDIO_SelfCal Lib "niHSDIO.DLL" (ByVal vi as Long) as Long
Public Declare Function niHSDIO_ResetDevice Lib "niHSDIO.DLL" (ByVal vi as Long) as Long


'* Set and Get Attribute Functions *
Public Declare Function niHSDIO_GetAttributeViInt32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,ByVal attrib as Long,ByRef value as Long) as Long
Public Declare Function niHSDIO_GetAttributeViReal64 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByRef value as Double) as Long
Public Declare Function niHSDIO_GetAttributeViString Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal bufSize as Long,ByVal value as String) as Long
Public Declare Function niHSDIO_GetAttributeViSession Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByRef value as Long) as Long
Public Declare Function niHSDIO_GetAttributeViBoolean Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByRef value as Integer) as Long

Public Declare Function niHSDIO_SetAttributeViInt32 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal value as Long) as Long
Public Declare Function niHSDIO_SetAttributeViReal64 Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal value as Double) as Long
Public Declare Function niHSDIO_SetAttributeViString Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal value as String) as Long
Public Declare Function niHSDIO_SetAttributeViSession Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal value as Long) as Long
Public Declare Function niHSDIO_SetAttributeViBoolean Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channelName as String,  ByVal attrib as Long,ByVal value as Integer) as Long


'* Calibration Functions *
Public Declare Function niHSDIO_InitExtCal Lib "niHSDIO.DLL" (ByVal resourceName as String,ByVal password as String,ByRef vi as Long) as Long
Public Declare Function niHSDIO_CalAdjustChannelVoltage Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channel as String) as Long
Public Declare Function niHSDIO_CalAdjustChannelSkew Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channel as String) as Long
Public Declare Function niHSDIO_CalAdjustTerminalSkew Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal channel as String) as Long
Public Declare Function niHSDIO_GetSelfCalSupported Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef selfCalSupported as Integer) as Long
Public Declare Function niHSDIO_GetSelfCalLastDateAndTime Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef year as long,ByRef month as long,ByRef day as Long,ByRef hour as Long,ByRef minute as Long) as Long
Public Declare Function niHSDIO_GetExtCalLastDateAndTime Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef year as long,ByRef month as long,ByRef day as Long,ByRef hour as Long,ByRef minute as Long) as Long
Public Declare Function niHSDIO_GetSelfCalLastTemp Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef temp as Double) as Long
Public Declare Function niHSDIO_GetExtCalLastTemp Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef temp as Double) as Long
Public Declare Function niHSDIO_GetExtCalRecommendedInterval Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef interval as Long) as Long
Public Declare Function niHSDIO_ChangeExtCalPassword Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal oldPassword as String,ByVal newPassword as String) as Long
Public Declare Function niHSDIO_SetCalUserDefinedInfo Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal info as String) as Long
Public Declare Function niHSDIO_GetCalUserDefinedInfo Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal info as String) as Long
Public Declare Function niHSDIO_GetCalUserDefinedInfoMaxSize Lib "niHSDIO.DLL" (ByVal vi as Long,ByRef infoSize as Long) as Long
Public Declare Function niHSDIO_CloseExtCal Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal action as Long) as Long
Public Declare Function niHSDIO_RecordExtCalVerification Lib "niHSDIO.DLL" (ByVal vi as Long,ByVal password as String) as Long

'***************************************************************************************************
'*------------------------------------------ Status Codes -----------------------------------------*
'***************************************************************************************************

Public Const IVI_SPECIFIC_ERROR_BASE			      = (&H80000000 + &H3FFA0000 + &H4000)
Public Const IVI_SPECIFIC_WARN_BASE			      = (&H3FFA0000 + &H4000)
'* Error codes *
Public Const  NIHSDIO_ERROR_INVALID_RESOURCE_DESCRIPTOR       =  (IVI_SPECIFIC_ERROR_BASE + 44)
Public Const  NIHSDIO_ERROR_INVALID_CHANNEL_STRING_SYNTAX     =  (IVI_SPECIFIC_ERROR_BASE + 2)
Public Const  NIHSDIO_ERROR_NO_DYNAMIC_LINES_ENABLED          =  (IVI_SPECIFIC_ERROR_BASE + 4)
Public Const  NIHSDIO_ERROR_SESSION_IN_RUNNING_STATE          =  (IVI_SPECIFIC_ERROR_BASE + 5)
Public Const  NIHSDIO_ERROR_ONLY_ONE_IDENTIFIER_ALLOWED       =  (IVI_SPECIFIC_ERROR_BASE + 6)
Public Const  NIHSDIO_ERROR_INVALID_LINE_STATE                =  (IVI_SPECIFIC_ERROR_BASE + 7)
Public Const  NIHSDIO_ERROR_MAX_TIME_EXCEEDED                 =  (IVI_SPECIFIC_ERROR_BASE + 8)
Public Const  NIHSDIO_ERROR_INCORRECT_DIGITAL_PATTERN         =  (IVI_SPECIFIC_ERROR_BASE + 9)
Public Const  NIHSDIO_ERROR_WAVEFORM_NOT_IN_MEMORY            =  (IVI_SPECIFIC_ERROR_BASE + 12)
Public Const  NIHSDIO_ERROR_WAVEFORM_EMPTY                    =  (IVI_SPECIFIC_ERROR_BASE + 62)
Public Const  NIHSDIO_ERROR_SCRIPT_NOT_IN_MEMORY              =  (IVI_SPECIFIC_ERROR_BASE + 3)
Public Const  NIHSDIO_ERROR_DIGITAL_WAVEFORM_EXPECTED         =  (IVI_SPECIFIC_ERROR_BASE + 13)
Public Const  NIHSDIO_ERROR_SCALED_DATA_WIDTH_FAILED          =  (IVI_SPECIFIC_ERROR_BASE + 14)
Public Const  NIHSDIO_ERROR_INVALID_REPEAT_COUNT              =  (IVI_SPECIFIC_ERROR_BASE + 16)
Public Const  NIHSDIO_ERROR_SET_WHEN_SESSION_RUNNING          =  (IVI_SPECIFIC_ERROR_BASE + 39)
Public Const  NIHSDIO_ERROR_GET_WHEN_SESSION_NOT_RUNNING      =  (IVI_SPECIFIC_ERROR_BASE + 45)
Public Const  NIHSDIO_ERROR_SESSION_NOT_IN_RUNNING_STATE      =  (IVI_SPECIFIC_ERROR_BASE + 17)
Public Const  NIHSDIO_ERROR_NO_WFMS_IN_MEM                    =  (IVI_SPECIFIC_ERROR_BASE + 18)
Public Const  NIHSDIO_ERROR_ACTIVE_WFM_NOT_SPECIFIED          =  (IVI_SPECIFIC_ERROR_BASE + 19)
Public Const  NIHSDIO_ERROR_RESOURCE_ALREADY_RESERVED         =  (IVI_SPECIFIC_ERROR_BASE + 20)
Public Const  NIHSDIO_ERROR_ROUTING_HARDWARE_BUSY             =  (IVI_SPECIFIC_ERROR_BASE + 21)
Public Const  NIHSDIO_ERROR_SAMPS_PER_REC_TOO_BIG             =  (IVI_SPECIFIC_ERROR_BASE + 22)
Public Const  NIHSDIO_ERROR_NO_SCRIPTS_IN_MEMORY              =  (IVI_SPECIFIC_ERROR_BASE + 23)
Public Const  NIHSDIO_ERROR_ACTIVE_SCRIPT_NOT_SPECIFIED       =  (IVI_SPECIFIC_ERROR_BASE + 24)
Public Const  NIHSDIO_ERROR_INSTRUMENT_NOT_SUPPORTED          =  (IVI_SPECIFIC_ERROR_BASE + 25)
Public Const  NIHSDIO_ERROR_DUPLICATE_CHANNEL_NAME            =  (IVI_SPECIFIC_ERROR_BASE + 26)
Public Const  NIHSDIO_ERROR_ACQUISITION_SESSION_ALREADY_OPEN  =  (IVI_SPECIFIC_ERROR_BASE + 27)
Public Const  NIHSDIO_ERROR_GENERATION_SESSION_ALREADY_OPEN   =  (IVI_SPECIFIC_ERROR_BASE + 28)
Public Const  NIHSDIO_ERROR_CHANNEL_NOT_PREV_TRISTATED        =  (IVI_SPECIFIC_ERROR_BASE + 29)
Public Const  NIHSDIO_ERROR_CHANNEL_RESERVED_FOR_GENERATION   =  (IVI_SPECIFIC_ERROR_BASE + 31)
Public Const  NIHSDIO_ERROR_SAMPLES_NOT_YET_AVAILABLE         =  (IVI_SPECIFIC_ERROR_BASE + 32)
Public Const  NIHSDIO_ERROR_WAVEFORM_PREVIOUSLY_ALLOCATED     =  (IVI_SPECIFIC_ERROR_BASE + 35)
Public Const  NIHSDIO_ERROR_ROUTE_RESOURCES_IN_USE_IN_SESSION =  (IVI_SPECIFIC_ERROR_BASE + 36)
Public Const  NIHSDIO_ERROR_INVALID_GENERATION_CLOCK_SOURCE   =  (IVI_SPECIFIC_ERROR_BASE + 41)
Public Const  NIHSDIO_ERROR_RUNTIME_ABORTED                   =  (IVI_SPECIFIC_ERROR_BASE + 47)
Public Const  NIHSDIO_ERROR_DEVICE_ABSENT_OR_UNAVAILABLE      =  (IVI_SPECIFIC_ERROR_BASE + 50)
Public Const  NIHSDIO_ERROR_INVALID_SIGNAL_IDENTIFIER         =  (IVI_SPECIFIC_ERROR_BASE + 52)
Public Const  NIHSDIO_ERROR_UNSUPPORTED_SOFTWARE_TRIGGER_TYPE =  (IVI_SPECIFIC_ERROR_BASE + 53)
Public Const  NIHSDIO_ERROR_UNSUPPORTED_EXPORT_SIGNAL_TYPE    =  (IVI_SPECIFIC_ERROR_BASE + 54)
Public Const  NIHSDIO_ERROR_UNKNOWN_CHANNEL_NAME              =  (IVI_SPECIFIC_ERROR_BASE + 15)
Public Const  NIHSDIO_ERROR_ATTRIBUTE_NOT_SUPPORTED           =  (IVI_SPECIFIC_ERROR_BASE + 30)
Public Const  NIHSDIO_ERROR_INTERNAL_SOFTWARE_ERROR           =  (IVI_SPECIFIC_ERROR_BASE + 1)
Public Const  NIHSDIO_ERROR_REFERENCE_PAUSE_TRIGGER_CONFLICT  =  (IVI_SPECIFIC_ERROR_BASE + 37)
Public Const  NIHSDIO_ERROR_CALIBRATION_SESSION_ALREADY_OPEN  =  (IVI_SPECIFIC_ERROR_BASE + 58)
Public Const  NIHSDIO_ERROR_FILE_SIGNAL_AND_CHANNEL_MISMATCH  =  (IVI_SPECIFIC_ERROR_BASE + 59)
Public Const  NIHSDIO_ERROR_VOLTAGE_CALIBRATION_FAILED        =  (IVI_SPECIFIC_ERROR_BASE + 60)
Public Const  NIHSDIO_ERROR_CALIBRATION_FUNCTION_NOT_SUPPORTED = (IVI_SPECIFIC_ERROR_BASE + 61)
Public Const  NIHSDIO_ERROR_DELAY_VALUE_INVALID_FOR_FREQUENCY =  (IVI_SPECIFIC_ERROR_BASE + 63)
Public Const  NIHSDIO_ERROR_READ_WRITE_FUNCTION_NOT_SUPPORTED =  (IVI_SPECIFIC_ERROR_BASE + 64)
Public Const  NIHSDIO_ERROR_INVALID_DATA_WIDTH                =  (IVI_SPECIFIC_ERROR_BASE + 65)
Public Const  NIHSDIO_ERROR_INVALID_CHANNEL_FOR_DATA_WIDTH    =  (IVI_SPECIFIC_ERROR_BASE + 66)
Public Const  NIHSDIO_ERROR_INVALID_CHANNEL_FOR_DATA_RATE_MULTIPLIER = (IVI_SPECIFIC_ERROR_BASE + 67)
Public Const  NIHSDIO_ERROR_SESSION_NOT_IN_COMMITED_STATE     =  (IVI_SPECIFIC_ERROR_BASE + 68)
Public Const  NIHSDIO_ERROR_WAVEFORM_DATA_WIDTH_MISMATCH      =  (IVI_SPECIFIC_ERROR_BASE + 70)
Public Const  NIHSDIO_ERROR_DIGITAL_STATE_NOT_SUPPORTED       =  (IVI_SPECIFIC_ERROR_BASE + 71)
Public Const  NIHSDIO_ERROR_TRISTATE_MEMORY_FULL              =  (IVI_SPECIFIC_ERROR_BASE + 72)
Public Const  NIHSDIO_ERROR_FAILED_TO_START_HARDWARE_COMPARE  =  (IVI_SPECIFIC_ERROR_BASE + 73)
Public Const  NIHSDIO_ERROR_SAMPLE_ERRORS_NOT_AVAILABLE       =  (IVI_SPECIFIC_ERROR_BASE + 74)
Public Const  NIHSDIO_ERROR_EXPECTED_DATA_FIFO_OVERFLOW       =  (IVI_SPECIFIC_ERROR_BASE + 77)
Public Const  NIHSDIO_ERROR_EXPECTED_DATA_GENERATION_ERROR    =  (IVI_SPECIFIC_ERROR_BASE + 78)
Public Const  NIHSDIO_ERROR_WAVEFORM_HARDWARE_COMPARE_MISMATCH =  (IVI_SPECIFIC_ERROR_BASE + 79)
Public Const  NIHSDIO_ERROR_INVALID_FUNCTION_FOR_HARDWARE_COMPARE =  (IVI_SPECIFIC_ERROR_BASE + 80)
Public Const  NIHSDIO_ERROR_DATATYPE_OF_WFM_NOT_SUPPORTED     =  (IVI_SPECIFIC_ERROR_BASE + 81)
Public Const  NIHSDIO_ERROR_EXPECTED_DATA_READY_TIMEOUT       =  (IVI_SPECIFIC_ERROR_BASE + 82)
Public Const  NIHSDIO_ERROR_SAMPLE_ERROR_BUFFER_OVERFLOW      =  (IVI_SPECIFIC_ERROR_BASE + 83)
Public Const  NIHSDIO_ERROR_INVALID_TRIGGER_TYPE_FOR_HARDWARE_COMPARE =  (IVI_SPECIFIC_ERROR_BASE + 84)
Public Const  NIHSDIO_ERROR_FILE_CONTAINS_MULTIPLE_WAVEFORMS  =  (IVI_SPECIFIC_ERROR_BASE + 85)


'* Warning codes *
Public Const  NIHSDIO_WARN_NSUP_ID_QUERY                     =  (IVI_SPECIFIC_WARN_BASE + 1)
Public Const  NIHSDIO_WARN_PLL_BECAME_UNLOCKED               =  (IVI_SPECIFIC_WARN_BASE + 2)

'****************************************************************************************************
'*----------------------------------------- End Include File ---------------------------------------*
'****************************************************************************************************




' #include "niHSDIOObsolete.h"

